@@ -78,6 +78,18 @@ class Coordinates(object):
         """
         return f'{self.point.x:.3f} {self.point.y:.3f} {self.point.z:.3f}'
 
+    def print_lla(self, radians=False, a=WGS84_A, e=WGS84_E) -> str:
+        """
+        >>> coordinates = Coordinates(4889803.653, 170755.706, 4078049.851)
+        >>> coordinates.print_lla()
+        '40.0000000N 2.0000000E 100.000m'
+        """
+        lla = LLA(*xyz_to_lla(*self.point, radians=radians, a=a, e=e))
+        lat_letter = 'N' if lla.latitude else 'S'
+        latitude = abs(lla.latitude)
+        lon_letter = 'E' if lla.longitude else 'W'
+        longitude = abs(lla.longitude)
+        return f"{latitude:.7f}{lat_letter} {longitude:.7f}{lon_letter} {lla.altitude:.3f}m"
 
     def __sub__(self, other) -> XYZ:
         """
